@@ -1,6 +1,6 @@
 /*
 
-   $Id: quote.c 10829 2008-02-26 13:10:38Z turnstep $
+   $Id: quote.c 10871 2008-03-03 16:50:04Z turnstep $
 
    Copyright (c) 2003-2008 Greg Sabino Mullane and others: see the Changes file
 
@@ -16,8 +16,6 @@ char * null_quote(const char *string, STRLEN len, STRLEN *retlen)
 	dTHX;
 	char *result;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%snull_quote\n", THEADER);
-
 	New(0, result, len+1, char);
 	strncpy(result,string,len);
 	result[len]='\0';
@@ -33,8 +31,6 @@ char * quote_string(const char *string, STRLEN len, STRLEN *retlen)
 	STRLEN oldlen = len;
 	const char * const tmp = string;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_string\n", THEADER);
-
 	(*retlen) = 2;
 	while (len > 0 && *string != '\0') {
 		if (*string == '\'' || *string == '\\') {
@@ -67,8 +63,6 @@ char * quote_geom(const char *string, STRLEN len, STRLEN *retlen)
 	char * result;
         const char *tmp;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_geom\n", THEADER);
-
 	len = 0; /* stops compiler warnings. Remove entirely someday */
 	tmp = string;
 	(*retlen) = 2;
@@ -96,8 +90,6 @@ char * quote_path(const char *string, STRLEN len, STRLEN *retlen)
 	char * result;
 	const char * const tmp = string;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_path\n", THEADER);
-
 	len = 0; /* stops compiler warnings. Remove entirely someday */
 	(*retlen) = 2;
 	while (*string != '\0') {
@@ -125,8 +117,6 @@ char * quote_circle(const char *string, STRLEN len, STRLEN *retlen)
 	char * result;
 	const char * const tmp = string;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_circle\n", THEADER);
-
 	len = 0; /* stops compiler warnings. Remove entirely someday */
 	(*retlen) = 2;
 	while (*string != '\0') {
@@ -155,8 +145,6 @@ char * quote_bytea(char *string, STRLEN len, STRLEN *retlen)
 	char * result;
 	STRLEN oldlen = len;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_bytea\n", THEADER);
-
 	result = string;
 	(*retlen) = 2;
 	while (len > 0) {
@@ -224,8 +212,6 @@ char * quote_bool(const char *value, STRLEN len, STRLEN *retlen)
 	long int int_value;
 	STRLEN	max_len=6;
 	
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_bool\n", THEADER);
-
 	len = 0;
 	if (isDIGIT(*(const char*)value)) {
 		/* For now -- will go away when quote* take SVs */
@@ -258,8 +244,6 @@ char * quote_integer(const char *value, STRLEN len, STRLEN *retlen)
         const int intval = *((const int*)value);
 	len = 0;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%squote_integer\n", THEADER);
-
 	New(0, result, max_len, char);
 	
 	if (0 == intval)
@@ -279,7 +263,6 @@ void dequote_char(const char *string, STRLEN *retlen)
 {
 	dTHX;
 	/* TODO: chop_blanks if requested */
-	if (TSTARTQ) TRC(DBILOGFP, "%sdequote_char\n", THEADER);
 	*retlen = strlen(string);
 }
 
@@ -287,7 +270,6 @@ void dequote_char(const char *string, STRLEN *retlen)
 void dequote_string(const char *string, STRLEN *retlen)
 {
 	dTHX;
-	if (TSTARTQ) TRC(DBILOGFP, "%sdequote_string\n", THEADER);
 	*retlen = strlen(string);
 }
 
@@ -298,8 +280,6 @@ void dequote_bytea(char *string, STRLEN *retlen)
 	dTHX;
 	char *result;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%sdequote_bytea\n", THEADER);
-
 	(*retlen) = 0;
 
 	if (NULL == string)
@@ -344,8 +324,6 @@ void dequote_sql_binary(char *string, STRLEN *retlen)
 {
 	dTHX;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%sdequote_sql_binary\n", THEADER);
-
 	/* We are going to retun a dequote_bytea(), JIC */
 	warn("Use of SQL_BINARY invalid in dequote()");
 	dequote_bytea(string, retlen);
@@ -359,8 +337,6 @@ void dequote_bool(char *string, STRLEN *retlen)
 {
 	dTHX;
 
-	if (TSTARTQ) TRC(DBILOGFP, "%sdequote_bool\n", THEADER);
-
 	switch(*string){
 	case 'f': *string = '0'; break;
 	case 't': *string = '1'; break;
@@ -375,7 +351,6 @@ void dequote_bool(char *string, STRLEN *retlen)
 void null_dequote(const char *string, STRLEN *retlen)
 {
 	dTHX;
-	if (TSTARTQ) TRC(DBILOGFP, "%snull_dequote\n", THEADER);
 	*retlen = strlen(string);
 
 }
